==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/persistence/jdo/metamodel/src/main/java/module-info.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
module org.apache.causeway.persistence.jdo.metamodel {
    requires lombok;
    requires org.apache.causeway.applib;
    requires org.apache.causeway.commons;
    requires org.apache.causeway.core.config;
    requires org.apache.causeway.core.metamodel;
    requires org.apache.causeway.core.runtime;
    requires org.apache.causeway.persistence.jdo.applib;
    requires org.apache.causeway.persistence.jdo.provider;
    requires javax.jdo;
    requires org.apache.causeway.security.api;
    requires org.datanucleus.store.rdbms;
    requires org.apache.causeway.persistence.commons;

    exports org.apache.causeway.persistence.jdo.metamodel;
    exports org.apache.causeway.persistence.jdo.metamodel.facets.object.persistencecapable;

    provides org.apache.causeway.core.config.beans.CausewayBeanTypeClassifier
        with org.apache.causeway.persistence.jdo.metamodel.beans.JdoBeanTypeClassifier;
}

==> causeway-bom-3.4.0-source-release.zip: causeway-bom-3.4.0/persistence/jdo/metamodel/src/main/java/module-info.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
module org.apache.causeway.persistence.jdo.metamodel {
    requires static lombok;
    requires org.apache.causeway.applib;
    requires org.apache.causeway.commons;
    requires org.apache.causeway.core.config;
    requires org.apache.causeway.core.metamodel;
    requires org.apache.causeway.core.runtime;
    requires org.apache.causeway.persistence.jdo.applib;
    requires org.apache.causeway.persistence.jdo.provider;
    requires javax.jdo;
    requires org.apache.causeway.security.api;
    requires org.datanucleus.store.rdbms;
    requires org.apache.causeway.persistence.commons;

    exports org.apache.causeway.persistence.jdo.metamodel;
    exports org.apache.causeway.persistence.jdo.metamodel.facets.object.persistencecapable;
    
}
